# Shining Pebbles

## Description

A collection of utility functions that enable treating a file system of multiple files as a pseudo-database, facilitating maintenance and operations across the large-scale file system.

## Use Cases

- RPA projects @ LIFE Asset Management

## Contact

- **June Young Park**, RPA Dev Team Lead at Life Asset Management
- Email: [juneyoungpaak@gmail.com](mailto:juneyoungpaak@gmail.com)
- **Life Asset Management**, A hedge fund and private equity management firm headquartered in the International Finance Center, Yeouido, South Korea, dedicated to enhancing corporate value and shareholder value.
